summaryrefslogtreecommitdiff
path: root/include/system.h
diff options
context:
space:
mode:
authorDiana Z <dzigterman@chromium.org>2020-11-24 14:21:09 -0700
committerCommit Bot <commit-bot@chromium.org>2020-12-04 05:39:57 +0000
commit832193295ddfcadeeddae2ef904c6428eacc9f60 (patch)
tree48e83d70043d4cb0026f52b9178f2d74ea5f048f /include/system.h
parent21cc691d17ec60a758934a1239e56afee1fb4ff0 (diff)
downloadchrome-ec-832193295ddfcadeeddae2ef904c6428eacc9f60.tar.gz
COIL: Rename SLEEP_MASK_I2C_CONTROLLER
Rename SLEEP_MASK_I2C_CONTROLLER and related comments. BRANCH=None BUG=None TEST=make -j buildall Signed-off-by: Diana Z <dzigterman@chromium.org> Change-Id: Ib49a5c6b07a203dc659ed65909292e5f1009d33f Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/ec/+/2558907 Reviewed-by: Daisuke Nojiri <dnojiri@chromium.org>
Diffstat (limited to 'include/system.h')
-rw-r--r--include/system.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/include/system.h b/include/system.h
index 4eed668e64..10484b512d 100644
--- a/include/system.h
+++ b/include/system.h
@@ -466,7 +466,7 @@ enum {
*/
SLEEP_MASK_AP_RUN = BIT(0), /* the main CPU is running */
SLEEP_MASK_UART = BIT(1), /* UART communication ongoing */
- SLEEP_MASK_I2C_MASTER = BIT(2), /* I2C master communication ongoing */
+ SLEEP_MASK_I2C_CONTROLLER = BIT(2), /* I2C controller comms ongoing */
SLEEP_MASK_CHARGING = BIT(3), /* Charging loop ongoing */
SLEEP_MASK_USB_PWR = BIT(4), /* USB power loop ongoing */
SLEEP_MASK_USB_PD = BIT(5), /* USB PD device connected */